@@ -17,14 +17,13 @@ class MissingValueDetectorTest(unittest.TestCase):
             logger.addHandler(logging.StreamHandler(sys.stdout))
         graphsignal.configure(
             api_key='k1',
+            deployment='d1',
             debug_mode=True)
 
     def tearDown(self):
         graphsignal.shutdown()
 
-    def test_build_stats_none(self):
+    def test_detect(self):
         mvd = MissingValueDetector()
-        for i in range(MissingValueDetector.MIN_BASELINE_SIZE):
-            self.assertFalse(mvd.detect('d1', {'null_count': 0}))
         self.assertTrue(mvd.detect('d1', {'null_count': 1}))
-        self.assertFalse(mvd.detect('d1', {'null_count': 1}))
+        self.assertFalse(mvd.detect('d1', {'null_count': 0}))
