@@ -18,6 +18,7 @@ class NumpyNDArrayProfilerTest(unittest.TestCase):
             logger.addHandler(logging.StreamHandler(sys.stdout))
         graphsignal.configure(
             api_key='k1',
+            deployment='d1',
             debug_mode=True)
 
     def tearDown(self):
@@ -32,6 +33,7 @@ class NumpyNDArrayProfilerTest(unittest.TestCase):
         self.assertEqual(
             profiler.compute_counts(np.asarray([[-1, 2.0, 0, np.inf], [1, 0, 0, np.nan]])), 
             {'element_count': 8, 
+            'byte_count': 64,
             'null_count': 0, 
             'nan_count': 1, 
             'inf_count': 1, 
